@@ -135,6 +135,8 @@ def get_http_handlers(descriptor: FileDescriptor, service_name: str, method: str
         user['groups'] = decoded_access_token['group_membership']
       if 'limited_dataset_group_name' in decoded_access_token:
         user['limited_dataset_group_name'] = decoded_access_token['limited_dataset_group_name']
+      if 'name' in decoded_access_token:
+        user['name'] = decoded_access_token['name']
       user_json = json.dumps(user).encode('ascii')
       user_b64 = b64encode(user_json).decode('utf-8')
       metadata = {'x-delphai-user': user_b64}
